@@ -6,18 +6,20 @@ More detailed description.
 """
 
 import multiprocessing as mp
-import warnings
 
+import ogr
 import pyproj
 from pyrasta.io_.files import _copy_to_file
 from pyrasta.tools.calculator import _op, _raster_calculation
 from pyrasta.tools.clip import _clip_raster_by_extent, _clip_raster_by_mask
 from pyrasta.tools.conversion import _resample_raster, _padding, _rescale_raster, \
     _align_raster, _extract_bands, _merge_bands, _read_array, _xy_to_2d_index, _read_value_at, \
-    _project_raster, _array_to_raster
+    _project_raster, _array_to_raster, _set_no_data, _set_data_type
 from pyrasta.exceptions import RasterBaseError
+from pyrasta.tools.filters import _sieve
 from pyrasta.tools.mask import _raster_mask
 from pyrasta.tools.merge import _merge
+from pyrasta.tools.polygonize import _polygonize
 from pyrasta.tools.rasterize import _rasterize
 from pyrasta.tools.stats import _histogram, _zonal_stats
 from pyrasta.tools.windows import _windowing
@@ -30,7 +32,7 @@ gdal.UseExceptions()
 
 class RasterBase:
 
-    def __init__(self, src_file, no_data=None):
+    def __init__(self, src_file):
         """ Raster class constructor
 
         Description
@@ -40,8 +42,6 @@ class RasterBase:
         ----------
         src_file: str
             valid path to raster file
-        no_data: int or float
-            Set no data value only if it is not already defined in raster file
         """
         try:
             self._gdal_dataset = gdal.Open(src_file)
@@ -49,12 +49,12 @@ class RasterBase:
             raise RasterBaseError('\nGDAL returns: \"%s\"' % e)
 
         # If NoData not defined, define here
-        for band in range(self.nb_band):
-            if no_data is not None:
-                if self._gdal_dataset.GetRasterBand(band + 1).GetNoDataValue() is None:
-                    self._gdal_dataset.GetRasterBand(band + 1).SetNoDataValue(no_data)
-                else:
-                    warnings.warn("No data value is already set, cannot overwrite.")
+        # for band in range(self.nb_band):
+        #     if no_data is not None:
+        #         if self._gdal_dataset.GetRasterBand(band + 1).GetNoDataValue() is None:
+        #             self._gdal_dataset.GetRasterBand(band + 1).SetNoDataValue(no_data)
+        #         else:
+        #             warnings.warn("No data value is already set, cannot overwrite.")
 
         self._gdal_driver = self._gdal_dataset.GetDriver()
         self._file = src_file
@@ -285,12 +285,35 @@ class RasterBase:
         """
         return _padding(self, pad_x, pad_y, value)
 
+    def polygonize(self, filename, band=1, layer_name="layer", field_name="unknown",
+                   ogr_driver=ogr.GetDriverByName("ESRI Shapefile"),
+                   is_8_connected=False, progress_bar=False):
+        """ Polygonize raster
+
+        Parameters
+        ----------
+        filename: str
+        band: int
+        layer_name: str
+        field_name: str
+        ogr_driver: ogr.Driver
+        is_8_connected: bool
+        progress_bar: bool
+
+        Returns
+        -------
+
+        """
+        return _polygonize(self, filename, band, layer_name,
+                           field_name, ogr_driver, is_8_connected,
+                           progress_bar)
+
     @classmethod
     def rasterize(cls, layer, projection, x_size, y_size, geo_transform,
                   burn_values=None, attribute=None,
                   gdal_driver=gdal.GetDriverByName("Gtiff"), nb_band=1,
                   data_type=gdal.GetDataTypeByName("Float32"), no_data=-999,
-                  all_touched=True):
+                  all_touched=True, progress_bar=False):
         """ Rasterize geographic layer
 
         Parameters
@@ -318,6 +341,8 @@ class RasterBase:
         no_data: int or float, default -999
             No data value
         all_touched: bool
+        progress_bar: bool
+            Is progress bar displayed ?
 
         Returns
         -------
@@ -325,7 +350,7 @@ class RasterBase:
         """
         return _rasterize(cls, layer, burn_values, attribute, gdal_driver, projection,
                           x_size, y_size, nb_band, geo_transform, data_type, no_data,
-                          all_touched)
+                          all_touched, progress_bar)
 
     @classmethod
     def raster_calculation(cls, rasters, fhandle, window_size=100,
@@ -449,19 +474,63 @@ class RasterBase:
         """
         return _rescale_raster(self, r_min, r_max)
 
-    def to_crs(self, crs):
-        """ Re-project raster onto new CRS
+    def set_no_data(self, no_data):
+        """ Set no data value in raster
 
         Parameters
         ----------
-        crs: int or str
-            valid CRS (Valid EPSG code, valid proj string, etc.)
+        no_data: int or float
+
+        Returns
+        -------
+        RasterBase
+
+        """
+        return _set_no_data(self, no_data)
+
+    def set_data_type(self, data_type):
+        """ Set data type
+
+        Parameters
+        ----------
+        data_type: str
+            Valid GDAL data type name
+
+        Returns
+        -------
+        RasterBase
+
+        """
+        return _set_data_type(self, gdal.GetDataTypeByName(data_type))
+
+    def sieve_filter(self, threshold=1, connectedness=4, progress_bar=False):
+        """ Apply sieve filter
+
+        Parameters
+        ----------
+        threshold: int
+        connectedness: int
+        progress_bar: bool
 
         Returns
         -------
 
         """
-        return _project_raster(self, crs)
+        return _sieve(self, threshold, connectedness, progress_bar)
+
+    def to_crs(self, crs):
+        """ Re-project raster onto new CRS
+
+        Parameters
+        ----------
+        crs: int or str or pyproj.CRS
+            valid CRS (Valid pyproj CRS, EPSG code, proj string, etc.)
+
+        Returns
+        -------
+
+        """
+        return _project_raster(self, pyproj.CRS(crs))
 
     def to_file(self, filename):
         """ Write raster copy to file
